View source: R/coupledMetropolis.R
| gibbsBinMix | R Documentation |
This function implements full Gibbs sampling to simulate an MCMC sample from the posterior distribution assuming known number of mixture components.
gibbsBinMix(alpha, beta, gamma, K, m, burn, data,
thinning, z.true, outputDir)
alpha |
First shape parameter of the Beta prior distribution (strictly positive). Defaults to 1. |
beta |
Second shape parameter of the Beta prior distribution (strictly positive). Defaults to 1. |
gamma |
|
K |
Number of clusters. |
m |
Number of MCMC iterations. |
burn |
Burn-in period. |
data |
Binary data. |
thinning |
Thinning of the simulated chain. |
z.true |
An optional vector of cluster assignments considered as the ground-truth clustering of the observations. Useful for simulations. |
outputDir |
Output directory. |
Not really used.
Panagiotis Papastamoulis
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.