View source: R/coupledMetropolis.R
| myDirichlet | R Documentation |
This function simulates random vectors from a Dirichlet distribution.
myDirichlet(alpha)
alpha |
Vector of positive numbers denoting the parameters of the Dirichlet distribution. |
Panagiotis Papastamoulis
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.