print.bbm.object: Print function

View source: R/coupledMetropolis.R

print.bbm.objectR Documentation

Print function

Description

This function prints a summary of objects returned by the coupledMetropolis function.

Usage

## S3 method for class 'bbm.object'
print(x, printSubset, ...)

Arguments

x

An object of class bbm.object, which is returned by the coupledMetropolis function.

printSubset

Logical indicating whether to print the header or the whole matrix of estimates. Default value: TRUE.

...

ignored.

Details

The function prints the estimated distribution of the number of clusters, the estimated number of observations assigned to each cluster after post-processing the output with three label switching algorithms, as well as the header of the posterior mean estimates of \theta_{kj} (probability of success for cluster k and feature j) (conditionally on the most probable number of clusters).

Author(s)

Panagiotis Papastamoulis


BayesBinMix documentation built on Aug. 20, 2026, 5:10 p.m.